## What's Changed

1. 修复：>= Python 3.12 版本下可能导致 LLM Tool 注册错误的问题。
2. 优化：更好地适配 Class 方式注册 LLM Tool 的场景。引入 `call` 方法。
3. 新增：`ConversationManager` 类支持 `add_message_pair` 方法，简化对话消息的添加操作。
4. 新增：增加对 Tool Parameters 的参数验证，确保工具参数符合 JSON Schema 标准。
5. 新增：增加 LLM Message Schema 定义，提升消息结构的规范性和一致性。
6. 新增：支持对 WebUI 的侧边栏模块进行自定义配置(入口在侧边栏下方的设置页中)。
